<?php


namespace AustraliaPost\Extensions\Business\Metaboxes\Labels;


use AustraliaPost\Extensions\Business\Endpoints\Endpoints_Factory;
use AustraliaPost\Extensions\Business\Helpers\Utilities;
use AustraliaPost\Metaboxes\Metabox;

class Label_Metabox extends Metabox {


	/**
	 * The single instance of the class.
	 *
	 * @var Label_Metabox
	 * @since 2.1.1
	 */
	protected static $_instance = null;

	/**
	 * @return Label_Metabox
	 */
	public static function get_instance(){
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function __construct() {

		add_action( 'admin_enqueue_scripts', [$this, 'enqueue_admin_scripts'] );

		parent::__construct();

	}

	public function enqueue_admin_scripts($hook)
	{
		if (isset($_GET['post']) && get_post_type($_GET['post']) === 'shop_order') {
			wp_enqueue_script('vue-app', plugin_dir_url( __FILE__ ) . 'app/dist/app.js', [], AUSPOST_CURRENT_VERSION, true);
			wp_enqueue_style('vue-css', plugin_dir_url( __FILE__ ) . 'app/dist/css/app.css', [], '1.0');
		}
	}

	public function adding_metabox( $post_type, $post )
	{
		if (get_post_type($post->ID) !== 'shop_order') {
			return;
		}

		add_meta_box(
			'wpruby_australia_post_new_label_printing',
			__('Australia Post Labels Printer', 'woocommerce-australia-post-pro'),
			[$this,'render_metabox'],
			'shop_order',
			'advanced',
			'high'
		);
	}

	public function render_metabox( $post )
	{
		try {
			$order = new \WC_Order($post->ID);
		}catch (\Exception $e) {
			return '';
		}

		$nonce = Endpoints_Factory::get_endpoints_nonce();
		$products = Utilities::get_postage_products(true);

		$shipment_products = [];
		foreach ($products as $product) {
			$shipment_products[] = [
				'product_id' => $product['product_id'],
				'type' => $product['type'],
			];
		}

		if (Utilities::isEParcel()) {
			$shipment_products = array_reverse($shipment_products);
		}

		$dist_path = plugin_dir_url( __FILE__ ) . 'app/dist/';
		$path = plugin_dir_path(__FILE__ ) . 'views/labels-metabox.php';
		$this->load_view($path, compact('order','shipment_products', 'nonce', 'dist_path'));
	}


	public function process_metabox( $order_id ) {}




}
